@@ -45,7 +45,7 @@ class KinesisDestination(
         import aws_cdk.aws_kinesis as kinesis
         import aws_cdk.aws_logs_destinations as logs_destinations
         
-        # stream is of type Stream
+        # stream: kinesis.Stream
         
         kinesis_destination = logs_destinations.KinesisDestination(stream)
     '''
@@ -84,11 +84,13 @@ class LambdaDestination(
 ):
     '''Use a Lambda Function as the destination for a log subscription.
 
+    :exampleMetadata: infused
+
     Example::
 
         import aws_cdk.aws_logs_destinations as destinations
-        # fn is of type Function
-        # log_group is of type LogGroup
+        # fn: lambda.Function
+        # log_group: logs.LogGroup
         
         
         logs.SubscriptionFilter(self, "Subscription",
